@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.19.1";
+our $VERSION = "v0.20.0";
 
 1;
 __END__
@@ -133,7 +133,7 @@ L<https://rxjs.dev/api/index/function/concat>
     rx_concat(
         rx_of(10, 20, 30),
         rx_of(10, 20, 30, 40),
-    )->subscribe($subscsriber);
+    )->subscribe($observer);
 
 =item rx_defer
 
@@ -313,6 +313,15 @@ Works like rxjs's "delay", except the parameter is in seconds instead of ms.
     # (pause 10 seconds) 0, 1, 2, 3
     rx_interval(1)->pipe( op_delay(10) )->subscribe($observer);
 
+=item op_distinct_until_changed
+
+L<https://rxjs.dev/api/operators/distinctUntilChanged>
+
+    # 10, undef, 20, 30, [], []
+    rx_of(10, 10, undef, undef, 20, 20, 20, 30, 30, [], [])->pipe(
+        op_distinct_until_changed(),
+    )->subscribe($observer);
+
 =item op_filter
 
 L<https://rxjs.dev/api/operators/filter>
@@ -377,6 +386,14 @@ L<https://rxjs.dev/api/operators/refCount>
 
 L<https://rxjs.dev/api/operators/scan>
 
+    # 0, 1, 3, 6, 10, ...
+    rx_interval(1)->pipe(
+        op_scan(sub {
+            my ($acc, $item) = @_;
+            return $acc + $item;
+        }, 0),
+    )->subscribe($observer);
+
 =item op_share
 
 L<https://rxjs.dev/api/operators/share>
