@@ -1,6 +1,6 @@
 package RxPerl::Mojo;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use RxPerl ':all';
 
