@@ -8,12 +8,12 @@ use RxPerl::Utils qw/ get_subscription_from_subscriber get_timer_subs /;
 use RxPerl::Subscription;
 
 use Carp 'croak';
-use Scalar::Util 'reftype';
+use Scalar::Util 'reftype', 'refaddr';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    op_delay op_filter op_map op_map_to op_merge_map op_multicast op_pairwise op_ref_count
-    op_scan op_share op_start_with op_switch_map op_take op_take_until op_tap
+    op_delay op_distinct_until_changed op_filter op_map op_map_to op_merge_map op_multicast
+    op_pairwise op_ref_count op_scan op_share op_start_with op_switch_map op_take op_take_until op_tap
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -81,6 +81,36 @@ sub op_delay {
     };
 }
 
+sub op_distinct_until_changed {
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $prev_value;
+            my $have_prev_value = 0;
+
+            my $own_subscriber = {
+                %$subscriber,
+                next => sub {
+                    my ($value) = @_;
+
+                    if (! $have_prev_value or ! _eqq($prev_value, $value)) {
+                        $subscriber->{next}->($value) if defined $subscriber->{next};
+                        $have_prev_value = 1;
+                        $prev_value = $value;
+                    }
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_filter {
     my ($filtering_sub) = @_;
 
@@ -504,4 +534,13 @@ sub op_tap {
     };
 }
 
+sub _eqq {
+    my ($x, $y) = @_;
+
+    defined $x or return !defined $y;
+    defined $y or return !!0;
+    ref $x eq ref $y or return !!0;
+    return length(ref $x) ? refaddr $x == refaddr $y : $x eq $y;
+}
+
 1;
